@@ -169,9 +169,11 @@ class Definition:
 		if not isinstance(values, list):
 			raise Config.exception_factory.create_input_error(field_fqn, 'Expected array, received: {0}'.format(type(values)))
 		items = []
+		i = 0
 		for entry in values:
-			item = Index.validate_input(None, field_fqn, field_name, self.data_format, entry, dependent_values)
+			item = Index.validate_input(None, field_fqn + '[' + str(i) + ']', field_name, self.data_format, entry, dependent_values)
 			items.append(item[field_name])
+			i = i + 1
 		results[field_name] = items
 
 	def _assign_value(self, results, field_fqn, field_name, definition, value, dependent_values):
